@@ -16,9 +16,9 @@ Options:
 """
 from docopt import docopt
 
-from tool.new import create_lesscode_project
-from tool.sqlacodegen import sqlacodegen
-from version import __version__
+from pkg.tool.new import create_lesscode_project
+from pkg.tool.sqlacodegen import sqlacodegen
+from pkg.version import __version__
 
 
 def main():
